@@ -213,6 +213,10 @@ int mutt_account_getpass (ACCOUNT* account)
 #ifdef USE_POP
   else if ((account->type == M_ACCT_TYPE_POP) && PopPass)
     strfcpy (account->pass, PopPass, sizeof (account->pass));
+#endif
+#ifdef USE_SMTP
+  else if ((account->type == M_ACCT_TYPE_SMTP) && SmtpPass)
+    strfcpy (account->pass, SmtpPass, sizeof (account->pass));
 #endif
   else
   {
