@@ -214,7 +214,7 @@ ADDRESS *mutt_get_address (ENVELOPE *env, char **pfxp)
 void mutt_create_alias (ENVELOPE *cur, ADDRESS *iadr)
 {
   ALIAS *new, *t;
-  char buf[LONG_STRING], prompt[SHORT_STRING], *pc;
+  char buf[LONG_STRING], tmp[LONG_STRING], prompt[SHORT_STRING], *pc;
   char *err = NULL;
   char fixed[LONG_STRING];
   FILE *rc;
@@ -231,15 +231,15 @@ void mutt_create_alias (ENVELOPE *cur, ADDRESS *iadr)
 
   if (adr && adr->mailbox)
   {
-    strfcpy (buf, adr->mailbox, sizeof (buf));
-    if ((pc = strchr (buf, '@')))
+    strfcpy (tmp, adr->mailbox, sizeof (tmp));
+    if ((pc = strchr (tmp, '@')))
       *pc = 0;
   }
   else
-    buf[0] = '\0';
+    tmp[0] = '\0';
 
   /* Don't suggest a bad alias name in the event of a strange local part. */
-  mutt_check_alias_name (buf, buf);
+  mutt_check_alias_name (tmp, buf, sizeof (buf));
   
 retry_name:
   /* add a new alias */
@@ -253,7 +253,7 @@ retry_name:
     return;
   }
   
-  if (mutt_check_alias_name (buf, fixed))
+  if (mutt_check_alias_name (buf, fixed, sizeof (fixed)))
   {
     switch (mutt_yesorno (_("Warning: This alias name may not work.  Fix it?"), M_YES))
     {
@@ -331,9 +331,27 @@ retry_name:
   if (mutt_get_field (_("Save to file: "), buf, sizeof (buf), M_FILE) != 0)
     return;
   mutt_expand_path (buf, sizeof (buf));
-  if ((rc = fopen (buf, "a")))
+  if ((rc = fopen (buf, "a+")))
   {
-    if (mutt_check_alias_name (new->name, NULL))
+    /* terminate existing file with \n if necessary */
+    if (fseek (rc, 0, SEEK_END))
+      goto fseek_err;
+    if (ftell(rc) > 0)
+    {
+      if (fseek (rc, -1, SEEK_CUR) < 0)
+	goto fseek_err;
+      if (fread(buf, 1, 1, rc) < 0)
+      {
+	mutt_perror (_("Error reading alias file"));
+	return;
+      }
+      if (fseek (rc, 0, SEEK_END) < 0)
+	goto fseek_err;
+      if (buf[0] != '\n')
+	fputc ('\n', rc);
+    }
+
+    if (mutt_check_alias_name (new->name, NULL, 0))
       mutt_quote_filename (buf, sizeof (buf), new->name);
     else
       strfcpy (buf, new->name, sizeof (buf));
@@ -347,6 +365,13 @@ retry_name:
   }
   else
     mutt_perror (buf);
+
+  return;
+  
+  fseek_err:
+  mutt_perror (_("Error seeking in alias file"));
+  fclose(rc);
+  return;
 }
 
 /* 
@@ -354,32 +379,42 @@ retry_name:
  * the RFC 822 and the mutt configuration parser are permitted.
  */
 
-static int check_alias_name_char (char c)
+int mutt_check_alias_name (const char *s, char *dest, size_t destlen)
 {
-  return (c == '-' || c == '_' || c == '+' || c == '=' || c == '.' ||
-	  isalnum ((unsigned char) c));
-}
+  wchar_t wc;
+  mbstate_t mb;
+  size_t l;
+  int rv = 0, bad = 0, dry = !dest || !destlen;
 
-int mutt_check_alias_name (const char *s, char *d)
-{
-  int rv = 0;
-  for (; *s; s++) 
+  memset (&mb, 0, sizeof (mbstate_t));
+
+  if (!dry)
+    destlen--;
+  for (; s && *s && (dry || destlen) &&
+       (l = mbrtowc (&wc, s, MB_CUR_MAX, &mb)) != 0;
+       s += l, destlen -= l)
   {
-    if (!check_alias_name_char (*s))
+    bad = l == (size_t)(-1) || l == (size_t)(-2); /* conversion error */
+    bad = bad || (!dry && l > destlen);		/* too few room for mb char */
+    if (l == 1)
+      bad = bad || (strchr ("-_+=.", *s) == NULL && !iswalnum (wc));
+    else
+      bad = bad || !iswalnum (wc);
+    if (bad)
     {
-      if (!d)
+      if (dry)
 	return -1;
-      else
-      {
-	*d++ = '_';
-	rv = -1;
-      }
+      *dest++ = '_';
+      rv = -1;
+    }
+    else if (!dry)
+    {
+      memcpy (dest, s, l);
+      dest += l;
     }
-    else if (d)
-      *d++ = *s;
   }
-  if (d)
-    *d++ = *s;
+  if (!dry)
+    *dest = 0;
   return rv;
 }
 
