@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */ 
 
 /* Close approximation of the mailx(1) builtin editor for sending mail. */
@@ -38,7 +38,7 @@
  * SLcurses_waddnstr() can't take a "const char *", so this is only
  * declared "static" (sigh)
  */
-static char* EditorHelp = N_("\
+static char* EditorHelp1 = N_("\
 ~~		insert a line begining with a single ~\n\
 ~b users	add users to the Bcc: field\n\
 ~c users	add users to the Cc: field\n\
@@ -47,7 +47,9 @@ static char* EditorHelp = N_("\
 ~h		edit the message header\n\
 ~m messages	include and quote messages\n\
 ~M messages	same as ~m, except include headers\n\
-~p		print the message\n\
+~p		print the message\n");
+
+static char* EditorHelp2 = N_("\
 ~q		write file and quit editor\n\
 ~r file		read a file into the editor\n\
 ~t users	add users to the To: field\n\
@@ -59,7 +61,7 @@ static char* EditorHelp = N_("\
 .		on a line by itself ends input\n");
 
 static char **
-be_snarf_data (FILE *f, char **buf, int *bufmax, int *buflen, int offset,
+be_snarf_data (FILE *f, char **buf, int *bufmax, int *buflen, LOFF_T offset,
 	       int bytes, int prefix)
 {
   char tmp[HUGE_STRING];
@@ -75,7 +77,7 @@ be_snarf_data (FILE *f, char **buf, int *bufmax, int *buflen, int offset,
     tmplen = sizeof (tmp) - tmplen;
   }
 
-  fseek (f, offset, 0);
+  fseeko (f, offset, 0);
   while (bytes > 0)
   {
     if (fgets (p, tmplen - 1, f) == NULL) break;
@@ -352,7 +354,8 @@ int mutt_builtin_editor (const char *path, HEADER *msg, HEADER *cur)
       switch (tmp[1])
       {
 	case '?':
-	  addstr (_(EditorHelp));
+	  addstr (_(EditorHelp1));
+          addstr (_(EditorHelp2));
 	  break;
 	case 'b':
 	  msg->env->bcc = mutt_parse_adrlist (msg->env->bcc, p);
