@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */ 
 
 #if HAVE_CONFIG_H
@@ -158,5 +158,5 @@ void hash_destroy (HASH **ptr, void (*destroy) (void *))
     }
   }
   FREE (&pptr->table);
-  FREE (ptr);
+  FREE (ptr);		/* __FREE_CHECKED__ */
 }
