@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ *     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #if HAVE_CONFIG_H
@@ -184,7 +184,7 @@ void mutt_edit_headers (const char *editor,
     else if ((WithCrypto & APPLICATION_PGP)
              &&ascii_strncasecmp ("pgp:", cur->data, 4) == 0)
     {
-      msg->security = mutt_parse_crypt_hdr (cur->data + 4, 0);
+      msg->security = mutt_parse_crypt_hdr (cur->data + 4, 0, APPLICATION_PGP);
       if (msg->security)
 	msg->security |= APPLICATION_PGP;
       keep = 0;
