@@ -160,7 +160,7 @@ void menu_pad_string (char *s, size_t n)
   int shift = option (OPTARROWCURSOR) ? 3 : 0;
   int cols = COLS - shift;
 
-  mutt_format_string (s, n, cols, cols, 0, ' ', scratch, mutt_strlen (scratch), 1);
+  mutt_format_string (s, n, cols, cols, FMT_LEFT, ' ', scratch, mutt_strlen (scratch), 1);
   s[n - 1] = 0;
   FREE (&scratch);
 }
@@ -206,7 +206,7 @@ void menu_redraw_status (MUTTMENU *menu)
 
 void menu_redraw_index (MUTTMENU *menu)
 {
-  char buf[STRING];
+  char buf[LONG_STRING];
   int i;
 
   for (i = menu->top; i < menu->top + menu->pagelen; i++)
@@ -262,7 +262,7 @@ void menu_redraw_index (MUTTMENU *menu)
 
 void menu_redraw_motion (MUTTMENU *menu)
 {
-  char buf[STRING];
+  char buf[LONG_STRING];
 
   if (menu->dialog) 
   {
@@ -322,7 +322,7 @@ void menu_redraw_motion (MUTTMENU *menu)
 
 void menu_redraw_current (MUTTMENU *menu)
 {
-  char buf[STRING];
+  char buf[LONG_STRING];
   
   move (menu->current + menu->offset - menu->top, 0);
   menu_make_entry (buf, sizeof (buf), menu, menu->current);
