@@ -397,7 +397,7 @@ char *_mutt_expand_path (char *s, size_t slen, int rx)
 	  strfcpy (p, NONULL (Maildir), sizeof (p));
 	else
 #endif
-	if (Maildir[strlen (Maildir) - 1] == '/')
+	if (Maildir && *Maildir && Maildir[strlen (Maildir) - 1] == '/')
 	  strfcpy (p, NONULL (Maildir), sizeof (p));
 	else
 	  snprintf (p, sizeof (p), "%s/", NONULL (Maildir));
@@ -1231,13 +1231,12 @@ void mutt_FormatString (char *dest,		/* output buffer */
 	  }
 	  else if (soft && pad < 0)
 	  {
-	    /* set wptr and wlen back just enough bytes to make sure buf
-	     * fits on screen, \0-terminate dest so mutt_wstr_trunc()
-	     * can correctly compute string's length */
-	    if (pad < -wlen)
-	      pad = -wlen;
+	    /* \0-terminate dest for length computation in mutt_wstr_trunc() */
 	    *wptr = 0;
-	    wlen = mutt_wstr_trunc (dest, wlen + pad, col + pad, &col);
+	    /* make sure right part is at most as wide as display */
+	    len = mutt_wstr_trunc (buf, destlen, COLS, &wid);
+	    /* truncate left so that right part fits completely in */
+	    wlen = mutt_wstr_trunc (dest, destlen - len, col + pad, &col);
 	    wptr = dest + wlen;
 	  }
 	  if (len + wlen > destlen)
