@@ -1238,12 +1238,25 @@ static void quote_simple(char *tmp, size_t len, const char *p)
 void mutt_check_simple (char *s, size_t len, const char *simple)
 {
   char tmp[LONG_STRING];
+  int do_simple = 1;
+  char *p;
+
+  for (p = s; p && *p; p++)
+  {
+    if (*p == '\\' && *(p + 1))
+      p++;
+    else if (*p == '~' || *p == '=' || *p == '%')
+    {
+      do_simple = 0;
+      break;
+    }
+  }
 
   /* XXX - is ascii_strcasecmp() right here, or should we use locale's
    * equivalences?
    */
-  
-  if (!strchr (s, '~') && !strchr (s, '=') && !strchr (s, '%')) /* yup, so spoof a real request */
+
+  if (do_simple) /* yup, so spoof a real request */
   {
     /* convert old tokens into the new format */
     if (ascii_strcasecmp ("all", s) == 0 ||
@@ -1318,7 +1331,7 @@ int mutt_pattern_func (int op, char *prompt)
 
     for (i = 0; i < Context->msgcount; i++)
     {
-      mutt_progress_update (&progress, i);
+      mutt_progress_update (&progress, i, -1);
       /* new limit pattern implicitly uncollapses all threads */
       Context->hdrs[i]->virtual = -1;
       Context->hdrs[i]->limited = 0;
@@ -1339,7 +1352,7 @@ int mutt_pattern_func (int op, char *prompt)
   {
     for (i = 0; i < Context->vcount; i++)
     {
-      mutt_progress_update (&progress, i);
+      mutt_progress_update (&progress, i, -1);
       if (mutt_pattern_exec (pat, M_MATCH_FULL_ADDRESS, Context, Context->hdrs[Context->v2r[i]]))
       {
 	switch (op)
@@ -1458,7 +1471,7 @@ int mutt_search_command (int cur, int op)
 
   for (i = cur + incr, j = 0 ; j != Context->vcount; j++)
   {
-    mutt_progress_update (&progress, j);
+    mutt_progress_update (&progress, j, -1);
     if (i > Context->vcount - 1)
     {
       i = 0;
