@@ -174,7 +174,7 @@ void pop_apop_timestamp (POP_DATA *pop_data, char *buf)
 /* APOP authenticator */
 static pop_auth_res_t pop_auth_apop (POP_DATA *pop_data, const char *method)
 {
-  MD5_CTX mdContext;
+  struct md5_ctx ctx;
   unsigned char digest[16];
   char hash[33];
   char buf[LONG_STRING];
@@ -193,12 +193,11 @@ static pop_auth_res_t pop_auth_apop (POP_DATA *pop_data, const char *method)
   mutt_message _("Authenticating (APOP)...");
 
   /* Compute the authentication hash to send to the server */
-  MD5Init (&mdContext);
-  MD5Update (&mdContext, (unsigned char *)pop_data->timestamp,
-	     strlen (pop_data->timestamp));
-  MD5Update (&mdContext, (unsigned char *)pop_data->conn->account.pass,
-	     strlen (pop_data->conn->account.pass));
-  MD5Final (digest, &mdContext);
+  md5_init_ctx (&ctx);
+  md5_process_bytes (pop_data->timestamp, strlen (pop_data->timestamp), &ctx);
+  md5_process_bytes (pop_data->conn->account.pass,
+		     strlen (pop_data->conn->account.pass), &ctx);
+  md5_finish_ctx (&ctx, digest);
 
   for (i = 0; i < sizeof (digest); i++)
     sprintf (hash + 2 * i, "%02x", digest[i]);
