@@ -128,6 +128,7 @@ int smime_valid_passphrase (void)
 
 static const char *_mutt_fmt_smime_command (char *dest,
 					    size_t destlen,
+					    size_t col,
 					    char op,
 					    const char *src,
 					    const char *prefix,
@@ -242,10 +243,10 @@ static const char *_mutt_fmt_smime_command (char *dest,
   }
 
   if (optional)
-    mutt_FormatString (dest, destlen, ifstring, _mutt_fmt_smime_command,
+    mutt_FormatString (dest, destlen, col, ifstring, _mutt_fmt_smime_command,
 		       data, 0);
   else if (flags & M_FORMAT_OPTIONAL)
-    mutt_FormatString (dest, destlen, elsestring, _mutt_fmt_smime_command,
+    mutt_FormatString (dest, destlen, col, elsestring, _mutt_fmt_smime_command,
 		       data, 0);
 
   return (src);
@@ -256,7 +257,7 @@ static const char *_mutt_fmt_smime_command (char *dest,
 static void mutt_smime_command (char *d, size_t dlen,
 				struct smime_command_context *cctx, const char *fmt)
 {
-  mutt_FormatString (d, dlen, NONULL(fmt), _mutt_fmt_smime_command,
+  mutt_FormatString (d, dlen, 0, NONULL(fmt), _mutt_fmt_smime_command,
 		    (unsigned long) cctx, 0);
   dprint (2,(debugfile, "mutt_smime_command: %s\n", d));
 }
@@ -858,8 +859,8 @@ static int smime_handle_cert_email (char *certificate, char *mailbox,
 
   fflush (fpout);
   rewind (fpout);
-  rewind (fperr);
   fflush (fperr);
+  rewind (fperr);
 
 
   while ((fgets (email, sizeof (email), fpout)))
@@ -953,8 +954,8 @@ static char *smime_extract_certificate (char *infile)
 
   fflush (fpout);
   rewind (fpout);
-  rewind (fperr);
   fflush (fperr);
+  rewind (fperr);
   empty = (fgetc (fpout) == EOF);
   if (empty)
   {
@@ -999,8 +1000,8 @@ static char *smime_extract_certificate (char *infile)
 
   fflush (fpout);
   rewind (fpout);
-  rewind (fperr);
   fflush (fperr);
+  rewind (fperr);
   empty =  (fgetc (fpout) == EOF);
   if (empty)
   {
@@ -1062,8 +1063,8 @@ static char *smime_extract_signer_certificate (char *infile)
 
   fflush (fpout);
   rewind (fpout);
-  rewind (fperr);
   fflush (fperr);
+  rewind (fperr);
   empty =  (fgetc (fpout) == EOF);
   if (empty)
   {
@@ -1749,6 +1750,7 @@ static BODY *smime_handle_entity (BODY *m, STATE *s, FILE *outFile)
 
   if (s->flags & M_DISPLAY)
   {
+    fflush (smimeerr);
     rewind (smimeerr);
     
     if ((c = fgetc (smimeerr)) != EOF)
