@@ -38,9 +38,18 @@
  *    missing.  Some systems only have snprintf() but not vsnprintf(), so
  *    the code is now broken down under HAVE_SNPRINTF and HAVE_VSNPRINTF.
  *
+ *  Holger Weiss <holger@zedat.fu-berlin.de> 07/23/06 for mutt 1.5.13
+ *    A C99 compliant [v]snprintf() returns the number of characters that
+ *    would have been written to a sufficiently sized buffer (excluding
+ *    the '\0').  Mutt now relies on this behaviour, but the original
+ *    code simply returned the length of the resulting output string, so
+ *    that's been fixed.
+ *
  **************************************************************/
 
-#include "config.h"
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
 
 #if !defined(HAVE_SNPRINTF) || !defined(HAVE_VSNPRINTF)
 
@@ -77,7 +86,7 @@
 /*int snprintf (char *str, size_t count, const char *fmt, ...);*/
 /*int vsnprintf (char *str, size_t count, const char *fmt, va_list arg);*/
 
-static void dopr (char *buffer, size_t maxlen, const char *format, 
+static int dopr (char *buffer, size_t maxlen, const char *format, 
                   va_list args);
 static void fmtstr (char *buffer, size_t *currlen, size_t maxlen,
 		    char *value, int flags, int min, int max);
@@ -119,7 +128,7 @@ static void dopr_outch (char *buffer, size_t *currlen, size_t maxlen, char c );
 #undef MAX
 #define MAX(p,q) ((p >= q) ? p : q)
 
-static void dopr (char *buffer, size_t maxlen, const char *format, va_list args)
+static int dopr (char *buffer, size_t maxlen, const char *format, va_list args)
 {
   char ch;
   long value;
@@ -139,7 +148,7 @@ static void dopr (char *buffer, size_t maxlen, const char *format, va_list args)
 
   while (state != DP_S_DONE)
   {
-    if ((ch == '\0') || (currlen >= maxlen)) 
+    if (ch == '\0')
       state = DP_S_DONE;
 
     switch(state) 
@@ -315,8 +324,6 @@ static void dopr (char *buffer, size_t maxlen, const char *format, va_list args)
 	break;
       case 's':
 	strvalue = va_arg (args, char *);
-	if (max < 0) 
-	  max = maxlen; /* ie, no max */
 	fmtstr (buffer, &currlen, maxlen, strvalue, flags, min, max);
 	break;
       case 'p':
@@ -370,6 +377,8 @@ static void dopr (char *buffer, size_t maxlen, const char *format, va_list args)
     buffer[currlen] = '\0';
   else 
     buffer[maxlen - 1] = '\0';
+
+  return (int)currlen;
 }
 
 static void fmtstr (char *buffer, size_t *currlen, size_t maxlen,
@@ -390,18 +399,18 @@ static void fmtstr (char *buffer, size_t *currlen, size_t maxlen,
   if (flags & DP_F_MINUS) 
     padlen = -padlen; /* Left Justify */
 
-  while ((padlen > 0) && (cnt < max)) 
+  while ((padlen > 0) && (max == -1 || cnt < max)) 
   {
     dopr_outch (buffer, currlen, maxlen, ' ');
     --padlen;
     ++cnt;
   }
-  while (*value && (cnt < max)) 
+  while (*value && (max == -1 || cnt < max)) 
   {
     dopr_outch (buffer, currlen, maxlen, *value++);
     ++cnt;
   }
-  while ((padlen < 0) && (cnt < max)) 
+  while ((padlen < 0) && (max == -1 || cnt < max)) 
   {
     dopr_outch (buffer, currlen, maxlen, ' ');
     ++padlen;
@@ -675,7 +684,8 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
 static void dopr_outch (char *buffer, size_t *currlen, size_t maxlen, char c)
 {
   if (*currlen < maxlen)
-    buffer[(*currlen)++] = c;
+    buffer[*currlen] = c;
+  (*currlen)++;
 }
 #endif /* !defined(HAVE_SNPRINTF) || !defined(HAVE_VSNPRINTF) */
 
@@ -683,8 +693,7 @@ static void dopr_outch (char *buffer, size_t *currlen, size_t maxlen, char c)
 int vsnprintf (char *str, size_t count, const char *fmt, va_list args)
 {
   str[0] = 0;
-  dopr(str, count, fmt, args);
-  return(strlen(str));
+  return(dopr(str, count, fmt, args));
 }
 #endif /* !HAVE_VSNPRINTF */
 
@@ -701,15 +710,16 @@ int snprintf (va_alist) va_dcl
   size_t count;
   char *fmt;
 #endif
+  int len;
   VA_LOCAL_DECL;
     
   VA_START (fmt);
   VA_SHIFT (str, char *);
   VA_SHIFT (count, size_t );
   VA_SHIFT (fmt, char *);
-  (void) vsnprintf(str, count, fmt, ap);
+  len = vsnprintf(str, count, fmt, ap);
   VA_END;
-  return(strlen(str));
+  return(len);
 }
 
 #ifdef TEST_SNPRINTF
